ArrayPropertiesSummary class

An object representing the array properties of a job.

Constructors

ArrayPropertiesSummary({int? index, int? size})
ArrayPropertiesSummary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int?
The job index within the array that's associated with this job. This parameter is returned for children of array jobs.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
The size of the array job. This parameter is returned for parent array jobs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited