AttemptContainerDetail class

An object representing the details of a container that's part of a job attempt.

Constructors

AttemptContainerDetail({String? containerInstanceArn, int? exitCode, String? logStreamName, List<NetworkInterface>? networkInterfaces, String? reason, String? taskArn})
AttemptContainerDetail.fromJson(Map<String, dynamic> json)
factory

Properties

containerInstanceArn → String?
The Amazon Resource Name (ARN) of the Amazon ECS container instance that hosts the job attempt.
final
exitCode → int?
The exit code for the job attempt. A non-zero exit code is considered a failure.
final
hashCode → int
The hash code for this object.
no setterinherited
logStreamName → String?
The name of the CloudWatch Logs log stream associated with the container. The log group for AWS Batch jobs is /aws/batch/job. Each container attempt receives a log stream name when they reach the RUNNING status.
final
networkInterfaces → List<NetworkInterface>?
The network interfaces associated with the job attempt.
final
reason → String?
A short (255 max characters) human-readable string to provide additional details about a running or stopped container.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskArn → String?
The Amazon Resource Name (ARN) of the Amazon ECS task that's associated with the job attempt. Each container attempt receives a task ARN when they reach the STARTING status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited