AttemptDetail class

An object representing a job attempt.

Constructors

AttemptDetail({AttemptContainerDetail? container, int? startedAt, String? statusReason, int? stoppedAt})
AttemptDetail.fromJson(Map<String, dynamic> json)
factory

Properties

container → AttemptContainerDetail?
Details about the container in this job attempt.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → int?
The Unix timestamp (in milliseconds) for when the attempt was started (when the attempt transitioned from the STARTING state to the RUNNING state).
final
statusReason → String?
A short, human-readable string to provide additional details about the current status of the job attempt.
final
stoppedAt → int?
The Unix timestamp (in milliseconds) for when the attempt was stopped (when the attempt transitioned from the RUNNING state to a terminal state, such as SUCCEEDED or FAILED).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited