describeJobDefinitions method
Describes a list of job definitions. You can specify a status
(such as ACTIVE) to only return job definitions that match
that status.
May throw ClientException. May throw ServerException.
Parameter jobDefinitionName :
The name of the job definition to describe.
Parameter jobDefinitions :
A list of up to 100 job definition names or full Amazon Resource Name
(ARN) entries.
Parameter maxResults :
The maximum number of results returned by
DescribeJobDefinitions in paginated output. When this
parameter is used, DescribeJobDefinitions only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another
DescribeJobDefinitions request with the returned
nextToken value. This value can be between 1 and 100. If this
parameter isn't used, then DescribeJobDefinitions returns up
to 100 results and a nextToken value if applicable.
Parameter nextToken :
The nextToken value returned from a previous paginated
DescribeJobDefinitions request where maxResults
was used and the results exceeded the value of that parameter. Pagination
continues from the end of the previous results that returned the
nextToken value. This value is null when there
are no more results to return.
Parameter status :
The status used to filter job definitions.
Implementation
Future<DescribeJobDefinitionsResponse> describeJobDefinitions({
String? jobDefinitionName,
List<String>? jobDefinitions,
int? maxResults,
String? nextToken,
String? status,
}) async {
final $payload = <String, dynamic>{
if (jobDefinitionName != null) 'jobDefinitionName': jobDefinitionName,
if (jobDefinitions != null) 'jobDefinitions': jobDefinitions,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
if (status != null) 'status': status,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/v1/describejobdefinitions',
exceptionFnMap: _exceptionFns,
);
return DescribeJobDefinitionsResponse.fromJson(response);
}