state property
The state of the compute environment. The valid values are
ENABLED or DISABLED.
If the state is ENABLED, then the AWS Batch scheduler can
attempt to place jobs from an associated job queue on the compute resources
within the environment. If the compute environment is managed, then it can
scale its instances out or in automatically, based on the job queue demand.
If the state is DISABLED, then the AWS Batch scheduler doesn't
attempt to place jobs within the environment. Jobs in a
STARTING or RUNNING state continue to progress
normally. Managed compute environments in the DISABLED state
don't scale out. However, they scale in to minvCpus value after
instances become idle.
Implementation
final CEState? state;