ulimits property
A list of ulimit values to set in the container. This parameter
maps to Ulimits in the Create a
container section of the Docker Remote API and
the --ulimit option to docker run.
Implementation
final List<Ulimit>? ulimits;
A list of ulimit values to set in the container. This parameter
maps to Ulimits in the Create a
container section of the Docker Remote API and
the --ulimit option to docker run.
final List<Ulimit>? ulimits;