CreateComputeEnvironmentResponse class

Constructors

CreateComputeEnvironmentResponse({String? computeEnvironmentArn, String? computeEnvironmentName})
CreateComputeEnvironmentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

computeEnvironmentArn → String?
The Amazon Resource Name (ARN) of the compute environment.
final
computeEnvironmentName → String?
The name of the compute environment. Up to 128 letters (uppercase and lowercase), numbers, hyphens, and underscores are allowed.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited