DescribeComputeEnvironmentsResponse class

Constructors

DescribeComputeEnvironmentsResponse({List<ComputeEnvironmentDetail>? computeEnvironments, String? nextToken})
DescribeComputeEnvironmentsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

computeEnvironments → List<ComputeEnvironmentDetail>?
The list of compute environments.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The nextToken value to include in a future DescribeComputeEnvironments request. When the results of a DescribeJobDefinitions request exceed maxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited