Device class

An object representing a container instance host device.

Constructors

Device({required String hostPath, String? containerPath, List<DeviceCgroupPermission>? permissions})
Device.fromJson(Map<String, dynamic> json)
factory

Properties

containerPath → String?
The path inside the container used to expose the host device. By default the hostPath value is used.
final
hashCode → int
The hash code for this object.
no setterinherited
hostPath → String
The path for the device on the host container instance.
final
permissions → List<DeviceCgroupPermission>?
The explicit permissions to provide to the container for the device. By default, the container has permissions for read, write, and mknod for the device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited