Ec2Configuration class

Provides information used to select Amazon Machine Images (AMIs) for instances in the compute environment. If the Ec2Configuration isn't specified, the default is ECS_AL1.

Constructors

Ec2Configuration({required String imageType, String? imageIdOverride})
Ec2Configuration.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageIdOverride → String?
The AMI ID used for instances launched in the compute environment that match the image type. This setting overrides the imageId set in the computeResource object.
final
imageType → String
The image type to match with the instance type to select an AMI. If the imageIdOverride parameter isn't specified, then a recent Amazon ECS-optimized AMI is used.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited