imageIdOverride property
The AMI ID used for instances launched in the compute environment that match
the image type. This setting overrides the imageId set in the
computeResource object.
Implementation
final String? imageIdOverride;
The AMI ID used for instances launched in the compute environment that match
the image type. This setting overrides the imageId set in the
computeResource object.
final String? imageIdOverride;