JobSummary class

An object representing summary details of a job.

Constructors

JobSummary({required String jobId, required String jobName, ArrayPropertiesSummary? arrayProperties, ContainerSummary? container, int? createdAt, String? jobArn, NodePropertiesSummary? nodeProperties, int? startedAt, JobStatus? status, String? statusReason, int? stoppedAt})
JobSummary.fromJson(Map<String, dynamic> json)
factory

Properties

arrayProperties → ArrayPropertiesSummary?
The array properties of the job, if it is an array job.
final
container → ContainerSummary?
An object representing the details of the container that's associated with the job.
final
createdAt → int?
The Unix timestamp for when the job was created. For non-array jobs and parent array jobs, this is when the job entered the SUBMITTED state (at the time SubmitJob was called). For array child jobs, this is when the child job was spawned by its parent and entered the PENDING state.
final
hashCode → int
The hash code for this object.
no setterinherited
jobArn → String?
The Amazon Resource Name (ARN) of the job.
final
jobId → String
The ID of the job.
final
jobName → String
The name of the job.
final
nodeProperties → NodePropertiesSummary?
The node properties for a single node in a job summary list.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → int?
The Unix timestamp for when the job was started (when the job transitioned from the STARTING state to the RUNNING state).
final
status → JobStatus?
The current status for the job.
final
statusReason → String?
A short, human-readable string to provide additional details about the current status of the job.
final
stoppedAt → int?
The Unix timestamp for when the job was stopped (when the job transitioned from the RUNNING state to a terminal state, such as SUCCEEDED or FAILED).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited