MountPoint class

Details on a Docker volume mount point that's used in a job's container properties. This parameter maps to Volumes in the Create a container section of the Docker Remote API and the --volume option to docker run.

Constructors

MountPoint({String? containerPath, bool? readOnly, String? sourceVolume})
MountPoint.fromJson(Map<String, dynamic> json)
factory

Properties

containerPath → String?
The path on the container where the host volume is mounted.
final
hashCode → int
The hash code for this object.
no setterinherited
readOnly → bool?
If this value is true, the container has read-only access to the volume. Otherwise, the container can write to the volume. The default value is false.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceVolume → String?
The name of the volume to mount.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited