NetworkConfiguration class

The network configuration for jobs running on Fargate resources. Jobs running on EC2 resources must not specify this parameter.

Constructors

NetworkConfiguration({AssignPublicIp? assignPublicIp})
NetworkConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

assignPublicIp → AssignPublicIp?
Indicates whether the job should have a public IP address. For a job running on Fargate resources in a private subnet to send outbound traffic to the internet (for example, in order to pull container images), the private subnet requires a NAT gateway be attached to route requests to the internet. For more information, see Amazon ECS task networking. The default value is "DISABLED".
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited