NetworkInterface class

An object representing the elastic network interface for a multi-node parallel job node.

Constructors

NetworkInterface({String? attachmentId, String? ipv6Address, String? privateIpv4Address})
NetworkInterface.fromJson(Map<String, dynamic> json)
factory

Properties

attachmentId → String?
The attachment ID for the network interface.
final
hashCode → int
The hash code for this object.
no setterinherited
ipv6Address → String?
The private IPv6 address for the network interface.
final
privateIpv4Address → String?
The private IPv4 address for the network interface.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited