NodePropertyOverride class

Object representing any node overrides to a job definition that's used in a SubmitJob API operation.

Constructors

NodePropertyOverride({required String targetNodes, ContainerOverrides? containerOverrides})

Properties

containerOverrides → ContainerOverrides?
The overrides that should be sent to a node range.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetNodes → String
The range of nodes, using node index values, that's used to override. A range of 0:3 indicates nodes with index values of 0 through 3. If the starting range value is omitted (:n), then 0 is used to start the range. If the ending range value is omitted (n:), then the highest possible node index is used to end the range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited