RegisterJobDefinitionResponse class

Constructors

RegisterJobDefinitionResponse({required String jobDefinitionArn, required String jobDefinitionName, required int revision})
RegisterJobDefinitionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobDefinitionArn → String
The Amazon Resource Name (ARN) of the job definition.
final
jobDefinitionName → String
The name of the job definition.
final
revision → int
The revision of the job definition.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited