ResourceRequirement class

The type and amount of a resource to assign to a container. The supported resources include GPU, MEMORY, and VCPU.

Constructors

ResourceRequirement({required ResourceType type, required String value})
ResourceRequirement.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ResourceType
The type of resource to assign to a container. The supported resources include GPU, MEMORY, and VCPU.
final
value → String
The quantity of the specified resource to reserve for the container. The values vary based on the type specified.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited