RetryStrategy class

The retry strategy associated with a job. For more information, see Automated job retries in the AWS Batch User Guide.

Constructors

RetryStrategy({int? attempts, List<EvaluateOnExit>? evaluateOnExit})
RetryStrategy.fromJson(Map<String, dynamic> json)
factory

Properties

attempts → int?
The number of times to move a job to the RUNNABLE status. You can specify between 1 and 10 attempts. If the value of attempts is greater than one, the job is retried on failure the same number of attempts as the value.
final
evaluateOnExit → List<EvaluateOnExit>?
Array of up to 5 objects that specify conditions under which the job should be retried or failed. If this parameter is specified, then the attempts parameter must also be specified.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited