Ulimit class

The ulimit settings to pass to the container.

Constructors

Ulimit({required int hardLimit, required String name, required int softLimit})
Ulimit.fromJson(Map<String, dynamic> json)
factory

Properties

hardLimit → int
The hard limit for the ulimit type.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The type of the ulimit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softLimit → int
The soft limit for the ulimit type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited